@@ -72,7 +72,6 @@ EVT_COMBOBOX( ID_COMBOACTCHANNEL, wxStfChildFrame::OnComboActChannel )
 EVT_COMBOBOX( ID_COMBOINACTCHANNEL, wxStfChildFrame::OnComboInactChannel )
 EVT_CHECKBOX( ID_ZERO_INDEX, wxStfChildFrame::OnZeroIndex)
 EVT_CHECKBOX( ID_PLOTSELECTED, wxStfChildFrame::OnShowselected )
-EVT_CHECKBOX( ID_SHOWSECOND, wxStfChildFrame::OnShowsecond )
 // workaround for status bar:
 EVT_MENU_HIGHLIGHT_ALL( wxStfChildFrame::OnMenuHighlight )
 END_EVENT_TABLE()
@@ -80,7 +79,7 @@ END_EVENT_TABLE()
 wxStfChildFrame::wxStfChildFrame(wxDocument* doc, wxView* view, wxStfParentType* parent,
                                  wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size,
                                  long style, const wxString& name) :
-wxStfChildType(doc,view,parent,id,title,pos,size,style,name),
+wxStfChildType(doc,view,parent,id,title,pos,size,style,name), m_parent(parent),
     m_notebook(NULL)
 {
     m_mgr.SetManagedWindow(this);
@@ -95,7 +94,7 @@ wxStfChildFrame::~wxStfChildFrame() {
 
 wxStfGrid* wxStfChildFrame::CreateTable() {
     // create the notebook off-window to avoid flicker
-    wxSize client_size = GetClientSize();
+    //wxSize client_size = GetClientSize();
 
     wxStfGrid* ctrl = new wxStfGrid( this, wxID_ANY,
                                      wxDefaultPosition, wxDefaultSize,
@@ -129,18 +128,17 @@ wxAuiNotebook* wxStfChildFrame::CreateNotebook() {
 }
 
 wxPanel* wxStfChildFrame::CreateTraceCounter() {
-    wxSize client_size = GetClientSize();
-    wxPanel* ctrl = new wxPanel( this, wxID_ANY, wxDefaultPosition,
-                                 wxSize(165,88) );
+    //wxSize client_size = GetClientSize();
+    wxPanel* ctrl = new wxPanel( this, wxID_ANY, wxDefaultPosition, wxDefaultSize
+                                 );// , wxSize(165,88) );
 
     return ctrl;
 }
 
 wxPanel* wxStfChildFrame::CreateChannelCounter() {
-    wxPanel* ctrl = new wxPanel( this, wxID_ANY, wxDefaultPosition,
-                                 wxSize(256,88) );
+    wxPanel* ctrl = new wxPanel( this, wxID_ANY, wxDefaultPosition, wxDefaultSize
+                                 ); //, wxSize(256,88) );
 
-    pChannelSizer = new wxFlexGridSizer( 2, 3, 2, 2 );
 
     return ctrl;
 }
@@ -150,53 +148,67 @@ void wxStfChildFrame::CreateMenuTraces(const std::size_t value) {
 
     m_traceCounter = CreateTraceCounter(); // this is wxPanel
 
-    wxBoxSizer* TracesSizer; // top-level Sizer
-    TracesSizer = new wxBoxSizer(wxVERTICAL);
+    wxBoxSizer* pTracesBoxSizer; // top-level Sizer
+    pTracesBoxSizer = new wxBoxSizer(wxVERTICAL);
 
     wxGridSizer* TracesGridSizer; // top-level GridSizer
     TracesGridSizer = new wxGridSizer(3,1,0,0);
 
-    // Grid
-    wxFlexGridSizer* TraceGridSizer;
-    TraceGridSizer = new wxFlexGridSizer(1,2,0,0); // 1 row, 2 columns for the SpinCtrl + text
+    // Grid for spin control
+    wxFlexGridSizer* pSpinCtrlTraceSizer;
+    pSpinCtrlTraceSizer = new wxFlexGridSizer(1,3,0,0); // 1 row, 3 columns for the SpinCtrl + text
 
     // 1) the wxSpinCtrl object 
     trace_spinctrl = new wxSpinCtrl( m_traceCounter, ID_SPINCTRLTRACES, wxEmptyString, wxDefaultPosition,
                      wxSize(64, wxDefaultCoord), wxSP_WRAP);
-    // by default, we start with non-zero based indices
-    trace_spinctrl->SetValue(1);
-    trace_spinctrl->SetRange(1,(int)sizemax);
 
     // the "of n", where n is the number of traces
+    // n is zero-based in zero-based check box is selected
+    wxStaticText* pIndexText;
+    pIndexText = new wxStaticText(m_traceCounter, wxID_ANY, wxT("Index: "));
     pSize=new wxStaticText( m_traceCounter, wxID_ANY, wxEmptyString);
     wxString sizeStr;
-    sizeStr << wxT("of ") << wxString::Format(wxT("%3d"),(int)sizemax);
-    pSize->SetLabel(sizeStr);
 
-    TraceGridSizer->Add( trace_spinctrl, 0, wxALIGN_LEFT  | wxALL, 1) ;
-    TraceGridSizer->Add( pSize,          0, wxALIGN_LEFT  | wxALIGN_CENTER | wxALL, 1) ;
+    pSpinCtrlTraceSizer->Add( pIndexText,     0, wxALIGN_CENTER_VERTICAL  | wxALL, 1) ;
+    pSpinCtrlTraceSizer->Add( trace_spinctrl, 0, wxALIGN_LEFT, 1) ;
+    pSpinCtrlTraceSizer->Add( pSize,          0, wxALIGN_LEFT  | wxALIGN_CENTER, 1) ;
 
-    // 2) Show zero-based index?
-    pZeroIndex = new wxCheckBox( m_traceCounter, ID_ZERO_INDEX, wxT("Zero-based index") );
-    //pZeroIndex->SetValue(false);
+    // 2) Show zero-based index? Read from Stimfit registry
+    pZeroIndex = new wxCheckBox( m_traceCounter, ID_ZERO_INDEX, wxT("Zero-based index ") );
     pZeroIndex->SetValue(wxGetApp().wxGetProfileInt(wxT("Settings"), wxT("Zeroindex"), 0));
 
+    // If true set the starting value to zero
+    if (pZeroIndex->GetValue()){
+        sizemax--;
+        trace_spinctrl->SetValue(0);
+        trace_spinctrl->SetRange(0, (int)sizemax);
+    }
+    else {
+        trace_spinctrl->SetValue(1);
+        trace_spinctrl->SetRange(1, (int)sizemax);
+    
+    }
+
+    // value argument is the number of traces
+    sizeStr << wxT(" of ") << wxString::Format(wxT("%3d"), value);
+    pSize->SetLabel(sizeStr);
     // Show selected
-    pShowSelected = new wxCheckBox( m_traceCounter, ID_PLOTSELECTED, wxT("Show selected "));
+    pShowSelected = new wxCheckBox( m_traceCounter, ID_PLOTSELECTED, wxT("Show selected       "));
     pShowSelected->SetValue(false);
 
-    // Add to UpGridSizer
-    TracesGridSizer->Add(TraceGridSizer, 0, wxALIGN_LEFT | wxALIGN_TOP | wxALL, 1);
-    TracesGridSizer->Add(pZeroIndex, 0, wxALIGN_LEFT | wxALIGN_BOTTOM | wxALL, 1);
-    TracesGridSizer->Add(pShowSelected, 0, wxALIGN_LEFT | wxALIGN_BOTTOM | wxALL, 1);
+    // Add everything to top-level GridSizer
+    TracesGridSizer->Add(pSpinCtrlTraceSizer, 0, wxALIGN_LEFT | wxALIGN_TOP    | wxALL, 3);
+    TracesGridSizer->Add(pZeroIndex,          0, wxALIGN_LEFT | wxALIGN_BOTTOM | wxALL, 3);
+    TracesGridSizer->Add(pShowSelected,       0, wxALIGN_LEFT | wxALIGN_BOTTOM | wxALL, 3);
 
-    TracesSizer->Add(TracesGridSizer, 0, wxALIGN_CENTER | wxALL, 1);
+    pTracesBoxSizer->Add(TracesGridSizer, 0, wxALIGN_CENTER | wxALL, 1);
 
-    m_traceCounter->SetSizer( TracesSizer );
+    pTracesBoxSizer->SetSizeHints(m_traceCounter);
+    m_traceCounter->SetSizer( TracesGridSizer );
     m_traceCounter->Layout();
-
+    wxSize size = m_traceCounter->GetSize();
     wxStfDoc* pDoc=(wxStfDoc*)GetDocument();
-    m_mgr.AddPane( m_traceCounter, wxAuiPaneInfo().Caption(wxT("Trace selection")).Fixed().
+    m_mgr.AddPane( m_traceCounter, wxAuiPaneInfo().Caption(wxT("Trace selection")).Fixed().BestSize(size.x, size.y).
                    Position(pDoc->size()-1).CloseButton(false).Floatable().Dock().Top().Name(wxT("SelectionT")) );
     m_table=CreateTable();
 
@@ -207,33 +219,69 @@ void wxStfChildFrame::CreateMenuTraces(const std::size_t value) {
 }
 // Channel Selection childframe
 void wxStfChildFrame::CreateComboChannels(const wxArrayString& channelStrings) {
-    m_channelCounter = CreateChannelCounter();
 
-    wxStaticText* pActIndex  = new wxStaticText( m_channelCounter, wxID_ANY, wxT("Active channel: ") );
-    pChannelSizer->Add( pActIndex );
+    m_channelCounter = CreateChannelCounter();
+    
+    wxBoxSizer* pChannelsBoxSizer; // top-level Sizer
+    pChannelsBoxSizer = new wxBoxSizer(wxVERTICAL);
+
+    wxGridSizer* ChannelsGridSizer; // top-level GridSizer
+    ChannelsGridSizer = new wxGridSizer(3,1,0,0);
+
+    // Grid for Active comboBox
+    wxBoxSizer* pComboActSizer;
+    pComboActSizer = new wxBoxSizer(wxHORIZONTAL);
+
+    wxStaticText* pActIndex  = new wxStaticText( m_channelCounter, wxID_ANY, wxT("Active channel:        ") );
 
     pActChannel = new wxComboBox( m_channelCounter, ID_COMBOACTCHANNEL, wxT("0"),
-                                  wxDefaultPosition, wxSize(64,24), channelStrings, wxCB_DROPDOWN | wxCB_READONLY );
-    pChannelSizer->Add( pActChannel );
-    pChannelSizer->AddStretchSpacer( );
+                                  wxDefaultPosition, wxSize(92, wxDefaultCoord), channelStrings, wxCB_DROPDOWN | wxCB_READONLY );
 
-    wxStaticText* pInactIndex = new wxStaticText( m_channelCounter, wxID_ANY, wxT("Inactive channel: ") );
+    pComboActSizer->Add( pActIndex,   0,  wxALIGN_CENTER_VERTICAL| wxALIGN_LEFT,  1);
+    pComboActSizer->Add( pActChannel, 0,  wxALIGN_CENTER_VERTICAL| wxALIGN_RIGHT, 1);
+
+    
+    // Grid for reference comboBox
+    wxBoxSizer* pComboRefSizer;
+    pComboRefSizer = new wxBoxSizer(wxHORIZONTAL);
+
+    wxStaticText* pInactIndex = new wxStaticText( m_channelCounter, wxID_ANY, wxT("Reference channel: ") );
     pInactIndex->SetForegroundColour( *wxRED );
-    pChannelSizer->Add( pInactIndex );
 
     pInactChannel = new wxComboBox( m_channelCounter, ID_COMBOINACTCHANNEL, wxT("1"),
-                                    wxDefaultPosition, wxSize(64,24), channelStrings, wxCB_DROPDOWN | wxCB_READONLY );
-    pChannelSizer->Add( pInactChannel );
-    
-    // Checkbox to hide inactive channel:
-    pShowSecond = new wxCheckBox( m_channelCounter, ID_PLOTSELECTED, wxT("Show") );
-    pShowSecond->SetValue(true);
-    pChannelSizer->Add( pShowSecond );
-    
-    m_channelCounter->SetSizer( pChannelSizer );
-    m_channelCounter->Layout();
+                                    wxDefaultPosition, wxSize(92,wxDefaultCoord), channelStrings, wxCB_DROPDOWN | wxCB_READONLY );
 
-    m_mgr.AddPane( m_channelCounter, wxAuiPaneInfo().Caption(wxT("Channel selection")).Fixed().
+    pComboRefSizer->Add( pInactIndex,   0,  wxALIGN_CENTER_VERTICAL | wxALIGN_LEFT , 1);
+    pComboRefSizer->Add( pInactChannel, 0,  wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT, 1 );
+    
+
+    wxBoxSizer *pShowChannelSizer;
+    pShowChannelSizer = new wxBoxSizer(wxHORIZONTAL);
+
+    // Checkbox to hide reference channel:
+    pShowSecond = new wxCheckBox( m_channelCounter, ID_PLOTSELECTED, wxT("Show reference") );
+    pShowSecond->SetForegroundColour( *wxRED );
+    pShowSecond->SetValue(true);
+    
+    pShowAll = new wxCheckBox( m_channelCounter, ID_PLOTSELECTED, wxT("Show all  ") );
+    pShowAll->SetValue(false);
+    pShowChannelSizer->Add( pShowAll );
+    pShowChannelSizer->Add( pShowSecond );
+    
+    // Add everything to top-level GridSizer
+    ChannelsGridSizer->Add(pComboActSizer,    0, wxALIGN_LEFT | wxALIGN_TOP    | wxALL, 3);
+    ChannelsGridSizer->Add(pComboRefSizer,    0, wxALIGN_LEFT | wxALIGN_BOTTOM | wxALL, 3);
+    ChannelsGridSizer->Add(pShowChannelSizer, 0, wxALIGN_LEFT | wxALIGN_BOTTOM | wxALL, 3);
+    
+
+    pChannelsBoxSizer->Add(ChannelsGridSizer, 0, wxALIGN_CENTER | wxALL, 1);
+
+    pChannelsBoxSizer->SetSizeHints(m_channelCounter);
+
+    m_channelCounter->SetSizer( ChannelsGridSizer );
+    m_channelCounter->Layout();
+    wxSize size = m_channelCounter->GetSize();
+    m_mgr.AddPane( m_channelCounter, wxAuiPaneInfo().Caption(wxT("Channel selection")).Fixed().BestSize(size.x, size.y).
                    Position(0).CloseButton(false).Floatable().Dock().Top().Name(wxT("SelectionC")) );
     m_mgr.Update();
 
@@ -282,7 +330,7 @@ void wxStfChildFrame::OnSpinCtrlTraces( wxSpinEvent& event ){
         return;
     }
 
-    pDoc->SetSection(GetCurTrace());
+    pDoc->SetSection(GetCurTrace()); 
     wxGetApp().OnPeakcalcexecMsg();
 
     if (pView->GetGraph() != NULL) {
@@ -383,24 +431,50 @@ void wxStfChildFrame::OnZeroIndex( wxCommandEvent& event) {
         return;
     }
     
-    // Check if  Zero-index is on
+    // If  Zero-index is ON (selected) 
     if (pZeroIndex->GetValue()){
         wxGetApp().wxWriteProfileInt(wxT("Settings"), wxT("Zeroindex"), 1); // write config
-        sizemax--;
-        pTraceCtrl->SetRange(0, sizemax);
-        pTraceCtrl->SetValue(pTraceCtrl->GetValue()-1);
+        if (pTraceCtrl->GetValue()==1){
+            sizemax--;
+            pTraceCtrl->SetRange(0, sizemax); // first set new range
+            pTraceCtrl->SetValue(pTraceCtrl->GetValue()-1); // now you can move one less 
+        }
+        else if (pTraceCtrl->GetValue()==(int)sizemax){
+            sizemax--;
+            pTraceCtrl->SetValue(pTraceCtrl->GetValue()-1); // move one less
+            pTraceCtrl->SetRange(0, sizemax); // next set new range
+        }
+        else {
+            sizemax--;
+            pTraceCtrl->SetRange(0, sizemax); // first set new range
+            pTraceCtrl->SetValue(pTraceCtrl->GetValue()-1); // now you can move one less 
+        }
         
     }
+    // If Zero-index is OFF (unselected) 
     else {
         wxGetApp().wxWriteProfileInt(wxT("Settings"), wxT("Zeroindex"), 0); 
-        sizemax++;
-        pTraceCtrl->SetRange(0, sizemax);
-        pTraceCtrl->SetValue(pTraceCtrl->GetValue()+1);
+        if (pTraceCtrl->GetValue()==0){
+            sizemax++;
+            pTraceCtrl->SetValue(pTraceCtrl->GetValue()+1); 
+            pTraceCtrl->SetRange(1, (int)sizemax); 
+        }
+        else if (pTraceCtrl->GetValue()==(int)sizemax){
+            sizemax++;
+            pTraceCtrl->SetRange(1, (int)sizemax); // first set new range
+            pTraceCtrl->SetValue(pTraceCtrl->GetValue()+1); // now you can move one more 
+        }
+        else { // now the order does not matter
+            sizemax++;
+            pTraceCtrl->SetRange(1, (int)sizemax); // first set new range
+            pTraceCtrl->SetValue(pTraceCtrl->GetValue()+1); // now you can move one more 
+        }
+        
     }
 
-    wxString sizeStr;
-    sizeStr << wxT("of ") << wxString::Format(wxT("%3d"),(int)sizemax);
-    pSize->SetLabel(sizeStr);
+    //wxString sizeStr;
+    //sizeStr << wxT("of ") << wxString::Format(wxT("%3d"),(int)sizemax);
+    //pSize->SetLabel(sizeStr);
 }
 
 void wxStfChildFrame::OnShowselected(wxCommandEvent& WXUNUSED(event)) {
@@ -412,15 +486,6 @@ void wxStfChildFrame::OnShowselected(wxCommandEvent& WXUNUSED(event)) {
     }
 }
 
-void wxStfChildFrame::OnShowsecond(wxCommandEvent& WXUNUSED(event)) {
-    wxStfView* pView=(wxStfView*)GetView();
-    if (pView != NULL && pView->GetGraph()!= NULL) { 
-        pView->GetGraph()->Refresh();
-        pView->GetGraph()->Enable();
-        pView->GetGraph()->SetFocus();
-    }
-}
-
 void wxStfChildFrame::ActivateGraph() {
     wxStfView* pView=(wxStfView*)GetView();
     // Set the focus somewhere else:
@@ -528,9 +593,11 @@ void wxStfChildFrame::Restoreperspective() {
 }
 
 void wxStfChildFrame::OnMenuHighlight(wxMenuEvent& event) {
-    wxMenuItem *item = this->GetMenuBar()->FindItem(event.GetId());
-    if(item) {
-        wxLogStatus(item->GetHelp());
+    if (this->GetMenuBar()) {
+        wxMenuItem *item = this->GetMenuBar()->FindItem(event.GetId());
+        if(item) {
+            wxLogStatus(item->GetHelp());
+        }
     }
     event.Skip();
 
