@@ -113,7 +113,7 @@ public:
     int GetSelCh1() const {return m_selChannel1;}
 
     //! Get selection for channel 2
-    /*! \return The index of the second (inactive) channel
+    /*! \return The index of the second (reference) channel
      */
     int GetSelCh2() const {return m_selChannel2;}
 };
@@ -663,11 +663,19 @@ class wxStfConvertDlg : public wxDialog
 private:
     wxDirPickerCtrl *m_srcDirPicker,*m_destDirPicker;
     wxTextCtrl *m_textCtrlSrcFilter;
-    wxString srcDir,destDir,srcFilter;
+    //wxComboBox *m_ComboBoxExt;
+    wxGenericDirCtrl *mySrcDirCtrl, *myDestDirCtrl; 
+    wxString srcDir,destDir;
+    wxString srcFilter;
+
+    stf::filetype srcFilterExt, destFilterExt;
     std::vector<wxString> srcFileNames;
 
     bool ReadPath(const wxString& path);
 
+    void OnComboBoxSrcExt(wxCommandEvent& event);
+    void OnComboBoxDestExt(wxCommandEvent& event);
+
     //! Only called when a modal dialog is closed with the OK button.
     /*! \return true if all dialog entries could be read successfully
      */
@@ -682,7 +690,7 @@ public:
      *  \param size Initial size.
      *  \param style Dialog style.
      */
-    wxStfConvertDlg( wxWindow* parent, int id = wxID_ANY, wxString title = wxT("Convert CFS files"),
+    wxStfConvertDlg( wxWindow* parent, int id = wxID_ANY, wxString title = wxT("Convert file series"),
             wxPoint pos = wxDefaultPosition, wxSize size = wxDefaultSize, int style = wxCAPTION );
 
     //! Get the source directory.
@@ -700,6 +708,16 @@ public:
      */
     wxString GetSrcFilter() const {return srcFilter;}
 
+    //! Get the source extension as std::filetype.
+    /*! \return The source extension as std::filetype.
+     */
+    stf::filetype GetSrcFileExt() const {return srcFilterExt;}
+
+    //! Get the destination extension as std::filetype.
+    /*! \return The destination extension as std::filetype.
+     */
+    stf::filetype GetDestFileExt() const {return destFilterExt;}
+
     //! Get the list of file names.
     /*! \return A vector with source file names.
      */
@@ -710,6 +728,7 @@ public:
      *         (e.g. wxID_OK)
      */
     virtual void EndModal(int retCode);
+
 };
 
 class wxListCtrl;
