@@ -46,7 +46,7 @@
 #include "./../core/filelib/atflib.h"
 #include "./../core/filelib/hdf5lib.h"
 #include "./../core/filelib/asciilib.h"
-#ifdef _WINDOWS
+#if 1//def _WINDOWS
 #include "./../core/filelib/igorlib.h"
 #endif
 #include "./usrdlg/usrdlg.h"
@@ -263,7 +263,7 @@ void wxStfDoc::SetData( const Recording& c_Data, const wxStfDoc* Sender, const w
         SetLatencyEndMode( Sender->GetLatencyEndMode() );
         SetLatencyWindowMode( Sender->GetLatencyWindowMode() );
         // Update menu checks:
-        UpdateMenuCheckmarks();
+        // UpdateMenuCheckmarks();
         //Get value of the peak direction dialog box
         SetDirection( Sender->GetDirection() );
         SetFromBase( Sender->GetFromBase() );
@@ -296,7 +296,7 @@ void wxStfDoc::SetData( const Recording& c_Data, const wxStfDoc* Sender, const w
     {
         SetLatencyStartMode(stf::manualMode);
         SetLatencyEndMode(stf::manualMode);
-        UpdateMenuCheckmarks();
+        // UpdateMenuCheckmarks();
     }
 
     // Make sure once again curChannel and curSection are not out of range:
@@ -337,7 +337,7 @@ int wxStfDoc::InitCursors() {
     SetLatencyEndMode(wxGetApp().wxGetProfileInt(wxT("Settings"),wxT("LatencyEndMode"),0));
     SetLatencyWindowMode(wxGetApp().wxGetProfileInt(wxT("Settings"),wxT("LatencyWindowMode"),1));
     // Set corresponding menu checkmarks:
-    UpdateMenuCheckmarks();
+    // UpdateMenuCheckmarks();
     SetPM(wxGetApp().wxGetProfileInt(wxT("Settings"),wxT("PeakMean"),1));
     wxString wxsSlope = wxGetApp().wxGetProfileString(wxT("Settings"),wxT("Slope"),wxT("20.0"));
     double fSlope = 0.0;
@@ -357,29 +357,6 @@ int wxStfDoc::InitCursors() {
     return wxID_OK;
 }	//End SettingsDlg()
 
-void wxStfDoc::UpdateMenuCheckmarks() {
-    // get menu bar:
-    wxStfChildFrame *pChildFrame = (wxStfChildFrame*)GetDocumentWindow();
-	if (pChildFrame) {
-
-#if 0
-        wxMenuBar *pBar=pChildFrame->GetMenuBar();
-        if (pBar) {
-            pBar->FindItem(ID_LATENCYSTART_MAXSLOPE)->Check(GetLatencyStartMode()==stf::riseMode);
-            pBar->FindItem(ID_LATENCYSTART_HALFRISE)->Check(GetLatencyStartMode()==stf::halfMode);
-            pBar->FindItem(ID_LATENCYSTART_PEAK)->Check(GetLatencyStartMode()==stf::peakMode);
-            pBar->FindItem(ID_LATENCYSTART_MANUAL)->Check(GetLatencyStartMode()==stf::manualMode);
-            pBar->FindItem(ID_LATENCYEND_FOOT)->Check(GetLatencyEndMode()==stf::footMode);
-            pBar->FindItem(ID_LATENCYEND_MAXSLOPE)->Check(GetLatencyEndMode()==stf::riseMode);
-            pBar->FindItem(ID_LATENCYEND_HALFRISE)->Check(GetLatencyEndMode()==stf::halfMode);
-            pBar->FindItem(ID_LATENCYEND_PEAK)->Check(GetLatencyEndMode()==stf::peakMode);
-            pBar->FindItem(ID_LATENCYEND_MANUAL)->Check(GetLatencyEndMode()==stf::manualMode);
-            pBar->FindItem(ID_LATENCYWINDOW)->Check(GetLatencyWindowMode()==stf::windowMode);
-	    }
-#endif
-    }
-}
-
 void wxStfDoc::PostInit() {
     wxStfChildFrame *pFrame = (wxStfChildFrame*)GetDocumentWindow();
     if ( pFrame == NULL ) {
@@ -422,21 +399,7 @@ void wxStfDoc::PostInit() {
             SetXScale(GetXScale()*1000.0);
         }
     }
-    if (size()>1) {
-        wxMenu* ch2Sub=new wxMenu;
-        ch2Sub->Append(ID_CH2BASE, wxT("Match &baseline"));
-        ch2Sub->Append(ID_CH2POS, wxT("Match &abs. position"));
-        ch2Sub->Append(ID_CH2ZOOM, wxT("Match &y-scale"));
-        ch2Sub->Append(ID_CH2BASEZOOM, wxT("Match baseline a&nd y-scale"));
-        wxStfChildFrame *pChildFrame = (wxStfChildFrame*)GetDocumentWindow();
-        wxMenuBar* pBar=pChildFrame->GetMenuBar();
 
-        if (pBar!=NULL) {
-            pBar->GetMenu(2)->AppendSeparator();
-            pBar->GetMenu(2)->AppendSubMenu(ch2Sub, wxT("&Channel 2 scaling"));
-            pBar->GetMenu(2)->Append(ID_SWAPCHANNELS, wxT("&Swap channels"));
-        }
-    }
     // Read results table settings from registry:
     SetViewCrosshair(wxGetApp().wxGetProfileInt(wxT("Settings"),wxT("ViewCrosshair"),1)==1);
     SetViewBaseline(wxGetApp().wxGetProfileInt(wxT("Settings"),wxT("ViewBaseline"),1)==1);
@@ -553,8 +516,10 @@ bool wxStfDoc::OnCloseDocument() {
         WriteToReg();
     }
     // Remove file menu from file menu list:
+#ifndef __WXGTK__
     wxGetApp().GetDocManager()->GetFileHistory()->RemoveMenu( doc_file_menu );
-
+#endif
+    
     // Tell the App:
     wxGetApp().CleanupDocument(this);
     return wxDocument::OnCloseDocument();
@@ -568,8 +533,8 @@ bool wxStfDoc::SaveAs() {
     filters += wxT("hdf5 file (*.h5)|*.h5|");
     filters += wxT("CED filing system (*.dat;*.cfs)|*.dat;*.cfs|");
     filters += wxT("Axon text file (*.atf)|*.atf|");
-    filters += wxT("Igor binary wave (*.*)|*.*|");
-    filters += wxT("Text file series (*.*)|*.*");
+    filters += wxT("Igor binary wave (*.ibw)|*.ibw|");
+    filters += wxT("Text file series (*.txt)|*.txt");
     wxFileDialog SelectFileDialog( GetDocumentWindow(), wxT("Save file"), wxT(""), wxT(""), filters,
             wxFD_SAVE | wxFD_OVERWRITE_PROMPT | wxFD_PREVIEW );
     if(SelectFileDialog.ShowModal()==wxID_OK) {
@@ -583,9 +548,9 @@ bool wxStfDoc::SaveAs() {
             case 2:
                 return stf::exportATFFile(filename, writeRec);
             case 3:
-#ifdef _WINDOWS
+                //#ifdef _WINDOWS
                 return stf::exportIGORFile(filename, writeRec);
-#else
+#if 0 //else
                 wxGetApp().ErrorMsg( wxT("Igor file export only implemented on Windows platforms") );
                 return false;
 #endif
@@ -875,7 +840,7 @@ void wxStfDoc::CreateAverage(
     //number of points in average:
     int average_size;
 
-    //find alignment points in the inactive (==second) channel:
+    //find alignment points in the reference (==second) channel:
     if (align) {
         wxStfAlignDlg AlignDlg(GetDocumentWindow());
         if (AlignDlg.ShowModal()!=wxID_OK) return;
@@ -908,7 +873,7 @@ void wxStfDoc::CreateAverage(
                 SetPeakEnd((int)get()[GetSecCh()][*cit].size()-1);
             }
             // Calculate all variables for the current settings
-            // APMaxSlopeT will be calculated for the second (==inactive)
+            // APMaxSlopeT will be calculated for the second (==reference)
             // channel, so channels may not be changed!
             try {
                 Measure();
@@ -1452,8 +1417,15 @@ void wxStfDoc::OnAnalysisBatch(wxCommandEvent &WXUNUSED(event)) {
 }
 
 void wxStfDoc::OnAnalysisIntegrate(wxCommandEvent &WXUNUSED(event)) {
-    double integral_s = stf::integrate_simpson(cur().get(),GetFitBeg(),GetFitEnd(),GetXScale());
-    double integral_t = stf::integrate_trapezium(cur().get(),GetFitBeg(),GetFitEnd(),GetXScale());
+    double integral_s = 0.0, integral_t = 0.0;
+    try {
+        integral_s = stf::integrate_simpson(cur().get(),GetFitBeg(),GetFitEnd(),GetXScale());
+        integral_t = stf::integrate_trapezium(cur().get(),GetFitBeg(),GetFitEnd(),GetXScale());
+    }
+    catch (const std::exception& e) {
+        wxGetApp().ErrorMsg(wxString( e.what(), wxConvLocal ));
+        return;
+    }
     stf::Table integralTable(6,1);
     try {
         integralTable.SetRowLabel(0, wxT("Trapezium (linear)"));
@@ -1572,7 +1544,7 @@ void wxStfDoc::Selectsome(wxCommandEvent &WXUNUSED(event)) {
     if (input.size()!=2) return;
     int everynth=(int)input[0];
     int everystart=(int)input[1];
-    div_t n_selected=div((int)get()[GetCurCh()].size(),everynth);
+    //div_t n_selected=div((int)get()[GetCurCh()].size(),everynth);
     for (int n=0; n*everynth+everystart-1 < (int)get()[GetCurCh()].size(); ++n) {
         try {
             SelectTrace(n*everynth+everystart-1);
@@ -1604,7 +1576,7 @@ void wxStfDoc::Unselectsome(wxCommandEvent &WXUNUSED(event)) {
     if (input.size()!=2) return;
     int everynth=(int)input[0];
     int everystart=(int)input[1];
-    div_t n_unselected=div((int)get()[GetCurCh()].size(),everynth);
+    //div_t n_unselected=div((int)get()[GetCurCh()].size(),everynth);
     for (int n=0; n*everynth+everystart-1 < (int)get()[GetCurCh()].size(); ++n) {
         UnselectTrace(n*everynth+everystart-1);
     }
