@@ -63,10 +63,10 @@
 #include "./printout.h"
 #include "./dlgs/smalldlgs.h"
 #include "./copygrid.h"
-#ifdef _WINDOWS
+//#ifdef _WINDOWS
 #include "./../core/filelib/atflib.h"
 #include "./../core/filelib/igorlib.h"
-#endif
+//#endif
 
 #include "./childframe.h"
 #include "./parentframe.h"
@@ -143,9 +143,9 @@ EVT_TOOL(ID_TOOL_LATENCY,wxStfParentFrame::OnToolLatency)
 EVT_TOOL(ID_TOOL_ZOOM,wxStfParentFrame::OnToolZoom)
 EVT_TOOL(ID_TOOL_EVENT,wxStfParentFrame::OnToolEvent)
 
-#ifdef _WINDOWS
+//#ifdef _WINDOWS
 EVT_MENU(ID_CONVERT, wxStfParentFrame::OnConvert)
-#endif
+//#endif
 EVT_MENU(ID_AVERAGE, wxStfParentFrame::OnAverage)
 EVT_MENU(ID_ALIGNEDAVERAGE, wxStfParentFrame::OnAlignedAverage)
 EVT_MENU( ID_VIEW_RESULTS, wxStfParentFrame::OnViewResults)
@@ -283,7 +283,9 @@ wxStfParentType(manager, frame, wxID_ANY, title, pos, size, type, _T("myFrame"))
                  << wxT("    win.plot_screen()\n")
                  << wxT("    return win\n");
 
-    RedirectStdio();
+    /*  The window remains open after the main application has been closed; deactivated for the time being.
+     *  RedirectStdio();
+     */
     wxWindow* pPython = DoPythonStuff(this, false);
     if ( pPython == 0 ) {
         wxGetApp().ErrorMsg(wxT("Can't create a window for the python shell\nPointer is zero"));
@@ -429,7 +431,7 @@ wxStfToolBar* wxStfParentFrame::CreateScaleTb() {
     scaleToolBar->AddTool( ID_TOOL_CH2,
                            wxT("Ch 2"),
                            wxBitmap(ch2_),
-                           wxT("Scaling applies to inactive (red) channel (\"2\")"),
+                           wxT("Scaling applies to reference (red) channel (\"2\")"),
                            wxITEM_CHECK );
     return scaleToolBar;
 }
@@ -637,7 +639,7 @@ bool CompVersion( const std::vector<int>& version ) {
 
 void wxStfParentFrame::CheckUpdate( wxProgressDialog* progDlg ) const {
     
-#ifdef __linux__
+#ifdef __LINUX__
     wxString address(wxT("/latest_linux"));
 #elif defined (_WINDOWS)
     wxString address(wxT("/latest_windows"));
@@ -702,9 +704,10 @@ void wxStfParentFrame::OnCheckUpdate(wxCommandEvent& WXUNUSED(event) )
     CheckUpdate( &progDlg );
 }
 
-#ifdef _WINDOWS
+//#ifdef _WINDOWS
 void wxStfParentFrame::OnConvert(wxCommandEvent& WXUNUSED(event) ) {
-    // Choose file type:
+    // Choose export file type:
+    /*
     std::vector< wxString > choices(2);
     choices[0] = wxT("Axon text file (*.atf)");
     choices[1] = wxT("Igor binary wave (*.ibw)");
@@ -723,14 +726,28 @@ void wxStfParentFrame::OnConvert(wxCommandEvent& WXUNUSED(event) ) {
      default:
          eft = stf::atf;
     }
+    */
+    int nfiles; // files to convert
+    wxString src_ext; // extension of the source file
+    wxString dest_ext; // extesion of the destiny file
+
+    // "Convert files" Dialog (see wxStfConvertDlg in smalldlgs.cpp)
     wxStfConvertDlg myDlg(this);
     if(myDlg.ShowModal()==wxID_OK) {
-		stf::filetype ift = stf::findType( myDlg.GetSrcFilter() );
-		wxMessageDialog Simple(this, myDlg.GetSrcFilter());
-		Simple.ShowModal();
+        //std::cout << myDlg.GetSrcFileExt() << std::endl;
+		stf::filetype ift = myDlg.GetSrcFileExt();
+		stf::filetype eft = myDlg.GetDestFileExt();
+        src_ext = myDlg.GetSrcFilter();
+
+        // wxProgressDialog
         wxProgressDialog progDlg( wxT("CFS conversion utility"), wxT("Starting file conversion"),
             100, NULL, wxPD_SMOOTH | wxPD_AUTO_HIDE | wxPD_APP_MODAL );
+
         std::vector<wxString> srcFilenames(myDlg.GetSrcFileNames());
+        nfiles = srcFilenames.size(); // number of files to convert
+        wxString myDestDir = myDlg.GetDestDir();
+        std::cout << myDestDir.c_str() << std::endl;
+
         for (std::size_t nFile=0; nFile<srcFilenames.size(); ++nFile) {
             wxString progStr;
 
@@ -738,7 +755,7 @@ void wxStfParentFrame::OnConvert(wxCommandEvent& WXUNUSED(event) ) {
             wxFileName srcWxFilename(srcFilenames[nFile]);
             wxString destFilename(
                                   myDlg.GetDestDir()+
-#ifdef __linux__
+#ifdef __LINUX__
                                   wxT("/")+
 #else
                                   wxT("\\")+
@@ -771,36 +788,55 @@ void wxStfParentFrame::OnConvert(wxCommandEvent& WXUNUSED(event) ) {
                         wxGetApp().set_txtImportSettings(ImportDlg.GetTxtImport());
                     }
                 }
+
                 stf::importFile(srcFilenames[nFile], ift, sourceFile, wxGetApp().GetTxtImport());
+
                 switch ( eft ) {
                  case stf::atf:
                      stf::exportATFFile( destFilename, sourceFile );
+                     dest_ext = wxT("Axon textfile [*.atf]");
                      break;
+
                  case stf::igor:
                      stf::exportIGORFile( destFilename, sourceFile );
+                     dest_ext = wxT("Igor binary file [*.ibw]");
                      break;
+
                  default:
                      wxString errorMsg(wxT("Unknown export file type\n"));
                      wxGetApp().ErrorMsg(errorMsg);
                      return;
                 }
             }
-            catch (const std::runtime_error& e) {
+           catch (const std::runtime_error& e) {
                 wxString errorMsg(wxT("Error opening file\n"));
-                errorMsg += wxString( e.what(),wxConvLocal );
+                errorMsg += wxT("Runtime Error\n");
+                errorMsg += wxString( e.what(), wxConvLocal );
                 wxGetApp().ExceptMsg(errorMsg);
                 return;
             }
+
             catch (const std::exception& e) {
                 wxString errorMsg(wxT("Error opening file\n"));
+                errorMsg += wxT("Exception\n");
                 errorMsg += wxString( e.what(), wxConvLocal );
                 wxGetApp().ExceptMsg(errorMsg);
                 return;
             }
         }
-    }
+    // Show now a smal information dialog
+    //std::count << srcFilter.c_str() << std::endl;
+    wxString msg;
+    msg = wxString::Format(wxT("%i"), nfiles);
+    msg << src_ext;
+    msg << wxT(" files \nwere converted to ");
+    msg << dest_ext;
+	wxMessageDialog Simple(this, msg);
+	Simple.ShowModal();
+    } // end of wxStfConvertDlg
+
 }
-#endif
+//#endif
 
 // Creates a graph. Called from view.cpp when a new drawing
 // view is created.
@@ -1104,7 +1140,7 @@ void wxStfParentFrame::OnViewResults(wxCommandEvent& WXUNUSED(event)) {
 void wxStfParentFrame::OnScale(wxCommandEvent& WXUNUSED(event)) {
     wxStfView* pView=wxGetApp().GetActiveView();
     if (pView!=NULL) {
-        if (GetActiveChild()->GetMenuBar()->GetMenu(2)->IsChecked(ID_SCALE)) {
+        if (GetActiveChild()->GetMenuBar() && GetActiveChild()->GetMenuBar()->GetMenu(2)->IsChecked(ID_SCALE)) {
             wxGetApp().wxWriteProfileInt(wxT("Settings"),wxT("ViewScaleBars"),1);
             wxGetApp().set_isBars(true);
         } else {
@@ -1119,7 +1155,7 @@ void wxStfParentFrame::OnScale(wxCommandEvent& WXUNUSED(event)) {
 void wxStfParentFrame::OnHires(wxCommandEvent& WXUNUSED(event)) {
     wxStfView* pView=wxGetApp().GetActiveView();
     if (pView!=NULL) {
-        if (GetActiveChild()->GetMenuBar()->GetMenu(2)->IsChecked(ID_HIRES)) {
+        if (GetActiveChild()->GetMenuBar() && GetActiveChild()->GetMenuBar()->GetMenu(2)->IsChecked(ID_HIRES)) {
             wxGetApp().wxWriteProfileInt(wxT("Settings"),wxT("ViewHiRes"),1);
 #ifndef __APPLE__
             wxGetApp().set_isHires(true);
@@ -1199,26 +1235,9 @@ void wxStfParentFrame::OnLStartMaxslope(wxCommandEvent& WXUNUSED(event)) {
         // toggle on if it wasn't the previous mode:
         //		if (!prevMode) {
         pDoc->SetLatencyStartMode(stf::riseMode);
-#if 0
-        // Uncheck the other choices:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MAXSLOPE,true);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_HALFRISE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_PEAK,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MANUAL,false);
-#endif
-        /*		} else {
-        // else, toggle to manual mode (default)
-        pDoc->SetLatencyStartMode(stf::manualMode);
-        // Check manual mode:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MANUAL,true);
-        // Uncheck (sometimes isn't done automatically):
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MAXSLOPE,false);
-        }
-        */		wxGetApp().wxWriteProfileInt(
-        wxT("Settings"),
-        wxT("LatencyStartMode"),
-        pDoc->GetLatencyStartMode()
-        );
+        wxGetApp().wxWriteProfileInt(wxT("Settings"),
+                                     wxT("LatencyStartMode"),
+                                     pDoc->GetLatencyStartMode());
         if (pView->GetGraph()!=NULL)
             pView->GetGraph()->Refresh();
     }
@@ -1228,25 +1247,12 @@ void wxStfParentFrame::OnLStartHalfrise(wxCommandEvent& WXUNUSED(event)) {
     wxStfView* pView=wxGetApp().GetActiveView();
     wxStfDoc* pDoc=wxGetApp().GetActiveDoc();
     if (pView!=NULL && pDoc!=NULL) {
-        //		if (GetActiveChild()->GetMenuBar()->GetMenu(1)->IsChecked(ID_LATENCYSTART_HALFRISE)) {
         pDoc->SetLatencyStartMode(stf::halfMode);
-#if 0
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_HALFRISE,true);
-        // Uncheck the other choices:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MAXSLOPE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_PEAK,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MANUAL,false);
-#endif 
-        /*		} else {
-        pDoc->SetLatencyStartMode(stf::manualMode);
-        // Check manual mode:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MANUAL,true);
-        }
-        */		wxGetApp().wxWriteProfileInt(
-        wxT("Settings"),
-        wxT("LatencyStartMode"),
-        pDoc->GetLatencyStartMode()
-        );
+        wxGetApp().wxWriteProfileInt(
+                                     wxT("Settings"),
+                                     wxT("LatencyStartMode"),
+                                     pDoc->GetLatencyStartMode()
+                                     );
         if (pView->GetGraph()!=NULL)
             pView->GetGraph()->Refresh();
     }
@@ -1257,21 +1263,7 @@ void wxStfParentFrame::OnLStartPeak(wxCommandEvent& WXUNUSED(event)) {
     wxStfView* pView=wxGetApp().GetActiveView();
     wxStfDoc* pDoc=wxGetApp().GetActiveDoc();
     if (pView!=NULL && pDoc!=NULL) {
-        //		if (GetActiveChild()->GetMenuBar()->GetMenu(1)->IsChecked(ID_LATENCYSTART_PEAK)) {
         pDoc->SetLatencyStartMode(stf::peakMode);
-#if 0
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_PEAK,true);
-        // Uncheck the other choices:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MAXSLOPE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_HALFRISE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MANUAL,false);
-#endif
-        /*		} else {
-        pDoc->SetLatencyStartMode(stf::manualMode);
-        // Check manual mode:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MANUAL,true);
-        }
-        */
         wxGetApp().wxWriteProfileInt( wxT("Settings"), wxT("LatencyStartMode"), pDoc->GetLatencyStartMode() );
         if (pView->GetGraph()!=NULL)
             pView->GetGraph()->Refresh();
@@ -1284,13 +1276,6 @@ void wxStfParentFrame::OnLStartManual(wxCommandEvent& WXUNUSED(event)) {
     if (pView!=NULL && pDoc!=NULL) {
         // Always keep manual mode as a default, even if attempted to uncheck:
         pDoc->SetLatencyStartMode(stf::manualMode);
-#if 0
-        // Uncheck the other choices:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MANUAL,true);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_MAXSLOPE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_HALFRISE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYSTART_PEAK,false);
-#endif
         wxGetApp().wxWriteProfileInt(
             wxT("Settings"),
             wxT("LatencyStartMode"),
@@ -1305,26 +1290,12 @@ void wxStfParentFrame::OnLEndFoot(wxCommandEvent& WXUNUSED(event)) {
     wxStfView* pView=wxGetApp().GetActiveView();
     wxStfDoc* pDoc=wxGetApp().GetActiveDoc();
     if (pView!=NULL && pDoc!=NULL) {
-        //		if (GetActiveChild()->GetMenuBar()->GetMenu(1)->IsChecked(ID_LATENCYEND_FOOT)) {
         pDoc->SetLatencyEndMode(stf::footMode);
-#if 0
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_FOOT,true);
-        // Uncheck the other choices:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MAXSLOPE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_HALFRISE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_PEAK,false);
-#endif 
-        /*		} else {
-        pDoc->SetLatencyEndMode(stf::manualMode);
-        // Check manual mode:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,true);
-        }
-        */		wxGetApp().wxWriteProfileInt(
-        wxT("Settings"),
-        wxT("LatencyEndMode"),
-        pDoc->GetLatencyEndMode()
-        );
+	wxGetApp().wxWriteProfileInt(
+                                     wxT("Settings"),
+                                     wxT("LatencyEndMode"),
+                                     pDoc->GetLatencyEndMode()
+                                     );
         if (pView->GetGraph()!=NULL)
             pView->GetGraph()->Refresh();
     }
@@ -1334,26 +1305,12 @@ void wxStfParentFrame::OnLEndMaxslope(wxCommandEvent& WXUNUSED(event)) {
     wxStfView* pView=wxGetApp().GetActiveView();
     wxStfDoc* pDoc=wxGetApp().GetActiveDoc();
     if (pView!=NULL && pDoc!=NULL) {
-        //		if (GetActiveChild()->GetMenuBar()->GetMenu(1)->IsChecked(ID_LATENCYEND_HALFRISE)) {
         pDoc->SetLatencyEndMode(stf::riseMode);
-#if 0
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MAXSLOPE,true);
-        // Uncheck the other choices:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_HALFRISE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_FOOT,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_PEAK,false);
-#endif
-        /*		} else {
-        pDoc->SetLatencyEndMode(stf::manualMode);
-        // Check manual mode:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,true);
-        }
-        */		wxGetApp().wxWriteProfileInt(
-        wxT("Settings"),
-        wxT("LatencyEndMode"),
-        pDoc->GetLatencyEndMode()
-        );
+        wxGetApp().wxWriteProfileInt(
+                                     wxT("Settings"),
+                                     wxT("LatencyEndMode"),
+                                     pDoc->GetLatencyEndMode()
+                                     );
         if (pView->GetGraph()!=NULL)
             pView->GetGraph()->Refresh();
     }
@@ -1363,22 +1320,7 @@ void wxStfParentFrame::OnLEndHalfrise(wxCommandEvent& WXUNUSED(event)) {
     wxStfView* pView=wxGetApp().GetActiveView();
     wxStfDoc* pDoc=wxGetApp().GetActiveDoc();
     if (pView!=NULL && pDoc!=NULL) {
-        //		if (GetActiveChild()->GetMenuBar()->GetMenu(1)->IsChecked(ID_LATENCYEND_HALFRISE)) {
         pDoc->SetLatencyEndMode(stf::halfMode);
-#if 0
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_HALFRISE,true);
-        // Uncheck the other choices:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MAXSLOPE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_FOOT,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_PEAK,false);
-#endif
-        /*		} else {
-        pDoc->SetLatencyEndMode(stf::manualMode);
-        // Check manual mode:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,true);
-        }
-        */
         wxGetApp().wxWriteProfileInt( wxT("Settings"), wxT("LatencyEndMode"), pDoc->GetLatencyEndMode() );
         if (pView->GetGraph()!=NULL)
             pView->GetGraph()->Refresh();
@@ -1389,22 +1331,7 @@ void wxStfParentFrame::OnLEndPeak(wxCommandEvent& WXUNUSED(event)) {
     wxStfView* pView=wxGetApp().GetActiveView();
     wxStfDoc* pDoc=wxGetApp().GetActiveDoc();
     if (pView!=NULL && pDoc!=NULL) {
-        //		if (GetActiveChild()->GetMenuBar()->GetMenu(1)->IsChecked(ID_LATENCYEND_PEAK)) {
         pDoc->SetLatencyEndMode(stf::peakMode);
-#if 0
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_PEAK,true);
-        // Uncheck the other choices:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MAXSLOPE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_FOOT,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_HALFRISE,false);
-#endif
-        /*		} else {
-        pDoc->SetLatencyEndMode(stf::manualMode);
-        // Check manual mode:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,true);
-        }
-        */
         wxGetApp().wxWriteProfileInt( wxT("Settings"), wxT("LatencyEndMode"), pDoc->GetLatencyEndMode() );
         if (pView->GetGraph()!=NULL)
             pView->GetGraph()->Refresh();
@@ -1416,22 +1343,7 @@ void wxStfParentFrame::OnLEndManual(wxCommandEvent& WXUNUSED(event)) {
     wxStfView* pView=wxGetApp().GetActiveView();
     wxStfDoc* pDoc=wxGetApp().GetActiveDoc();
     if (pView!=NULL && pDoc!=NULL) {
-        //		if (GetActiveChild()->GetMenuBar()->GetMenu(1)->IsChecked(ID_LATENCYEND_MANUAL)) {
         pDoc->SetLatencyEndMode(stf::manualMode);
-#if 0
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,true);
-        // Uncheck the other choices:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MAXSLOPE,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_PEAK,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_FOOT,false);
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_HALFRISE,false);
-#endif
-        /*		} else {
-        pDoc->SetLatencyEndMode(stf::manualMode);
-        // Check manual mode:
-        GetActiveChild()->GetMenuBar()->GetMenu(1)->Check(ID_LATENCYEND_MANUAL,true);
-        }
-        */
         wxGetApp().wxWriteProfileInt( wxT("Settings"), wxT("LatencyEndMode"), pDoc->GetLatencyEndMode() );
         if (pView->GetGraph()!=NULL)
             pView->GetGraph()->Refresh();
@@ -1444,7 +1356,7 @@ void wxStfParentFrame::OnLWindow(wxCommandEvent& WXUNUSED(event)) {
     wxStfDoc* pDoc=wxGetApp().GetActiveDoc();
     if (pView!=NULL) {
         // Select
-        if (GetActiveChild()->GetMenuBar()->GetMenu(1)->IsChecked(ID_LATENCYWINDOW)) {
+        if (GetActiveChild()->GetMenuBar() && GetActiveChild()->GetMenuBar()->GetMenu(1)->IsChecked(ID_LATENCYWINDOW)) {
             wxGetApp().wxWriteProfileInt( wxT("Settings"), wxT("LatencyWindowMode"), stf::windowMode );
             pDoc->SetLatencyWindowMode(stf::windowMode);
         } else {
