@@ -29,6 +29,7 @@
 #include "./filelib/atflib.h"
 #include "./filelib/axglib.h"
 #include "./filelib/hekalib.h"
+#include "./filelib/igorlib.h"
 #ifdef WITH_BIOSIG
 #include "./filelib/biosiglib.h"
 #endif
@@ -39,6 +40,7 @@
 
 stf::filetype
 stf::findType(const wxString& ext) {
+    
     if (ext==wxT("*.dat;*.cfs")) return stf::cfs;
     else if (ext==wxT("*.abf")) return stf::abf;
     else if (ext==wxT("*.axgd;*.axgx")) return stf::axg;
@@ -46,6 +48,7 @@ stf::findType(const wxString& ext) {
     else if (ext==wxT("*.atf")) return stf::atf;
     else if (ext==wxT("*.dat")) return stf::heka;
     else if (ext==wxT("*.smr")) return stf::son;
+
 #ifdef WITH_BIOSIG
     else if (ext==wxT("*.bs")) return stf::biosig;
 #endif
@@ -143,8 +146,12 @@ bool stf::exportFile(const wxString& fName, stf::filetype type, const Recording&
             stf::exportHDF5File(fName, Data);
             break;
         }
+        case stf::igor: {
+            stf::exportIGORFile(fName, Data);
+            break;
+        }
         default:
-            throw std::runtime_error("Only hdf5 is supported for writing at present.");
+            throw std::runtime_error("Only hdf5 and IGOR are supported for writing at present.");
         }
     }
     catch (...) {
