@@ -17,7 +17,7 @@
 #include "../Common/FileIO.hpp"
 #include "./abfutil.h"
 
-#if defined(__linux__) || defined(__STF__) || defined(__APPLE__)
+#if defined(__LINUX__) || defined(__STF__) || defined(__APPLE__)
 	#define max(a,b)   (((a) > (b)) ? (a) : (b))
 	#define min(a,b)   (((a) < (b)) ? (a) : (b))
 #endif
