@@ -458,7 +458,7 @@ bool set_channel(int channel) {
         return true;
     }
 
-    int inactive_ch = actDoc()->GetCurCh();  
+    int reference_ch = actDoc()->GetCurCh();  
         
     // catch exceptions (i.e out of range)
     try {
@@ -477,7 +477,7 @@ bool set_channel(int channel) {
     }
     // set the channel selection combo 
     //pFrame->SetChannels( actDoc()->GetCurCh(), actDoc()->GetSecCh()); 
-    pFrame->SetChannels( actDoc()->GetCurCh(), inactive_ch); 
+    pFrame->SetChannels( actDoc()->GetCurCh(), reference_ch); 
     pFrame->UpdateChannels(); // update according to the combo
     return refresh_graph();
 }
@@ -662,6 +662,22 @@ double get_threshold_value( ) {
 
 }
 
+double get_latency( ) {
+    if ( !check_doc() ) return -1.0;
+        
+        double dt = actDoc()->GetXScale();
+        return ( actDoc()->GetLatency() )*dt;
+
+}
+
+double get_risetime( ) {
+    if ( !check_doc() ) return -1.0;
+
+    double dt = actDoc()->GetXScale();
+    return ( actDoc()->GetT80Real()-actDoc()->GetT20Real() )*dt;
+    
+}
+
 double get_fit_start( bool is_time ) {
     if ( !check_doc() ) return -1;
 
@@ -805,6 +821,20 @@ int get_peak_mean() {
     return (int)actDoc()->GetPM();
 }
 
+const char* get_peak_direction( ) {
+    if ( !check_doc() ) return "";
+    
+    const char *direction = "both";
+    if ( actDoc()->GetDirection() == stf::up )
+        direction = "up";
+    else if ( actDoc()->GetDirection() == stf::down )
+        direction = "down";
+    else if ( actDoc()->GetDirection() == stf::both )
+        direction = "both";
+    
+    return direction;
+}
+
 bool set_peak_direction( const char* direction ) {
     if ( !check_doc() ) return false;
 
@@ -1107,7 +1137,7 @@ void align_selected(  double (*alignment)( bool ), bool active ) {
             pDoc->SetPeakEnd((int)pDoc->get()[pDoc->GetSecCh()][*cit].size()-1);
         }
         // Calculate all variables for the current settings
-        // APMaxSlopeT will be calculated for the second (==inactive)
+        // APMaxSlopeT will be calculated for the second (==reference)
         // channel, so channels may not be changed!
         try {
             pDoc->Measure();
